darkhistory.history.histools.IonRSInterp
========================================

.. currentmodule:: darkhistory.history.histools

.. autoclass:: IonRSInterp

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~IonRSInterp.__init__
      ~IonRSInterp.get_val
   
   

   
   
   